@@ -12,6 +12,7 @@ from flask_wtf.csrf import CsrfProtect
 from flask.ext.uploads import configure_uploads
 from flask_debugtoolbar import DebugToolbarExtension
 from werkzeug.wsgi import SharedDataMiddleware
+from werkzeug.contrib.fixers import ProxyFix
 from .utils.account import get_current_user
 from config import load_config
 
@@ -27,6 +28,9 @@ def create_app():
     config = load_config()
     app.config.from_object(config)
 
+    # Proxy fix
+    app.wsgi_app = ProxyFix(app.wsgi_app)
+
     # CSRF protect
     CsrfProtect(app)
 
@@ -68,8 +72,10 @@ def register_jinja(app):
     # inject vars into template context
     @app.context_processor
     def inject_vars():
+        from .utils import permissions
+
         return dict(
-            g_var=0
+            permissions=permissions
         )
 
     def url_for_other_page(page):
@@ -124,9 +130,10 @@ def register_db(app):
 
 def register_routes(app):
     """注册路由"""
-    from .controllers import site
+    from .controllers import site, account
 
     app.register_blueprint(site.bp, url_prefix='')
+    app.register_blueprint(account.bp, url_prefix='/account')
 
 
 def register_error_handle(app):
