@@ -8,4 +8,4 @@ class DevelopmentConfig(Config):
 
     # SQLAlchemy config
     # 如果是空密码，则直接将password删除即可
-    SQLALCHEMY_DATABASE_URI = "mysql://root:password@localhost/#{project}"
+    SQLALCHEMY_DATABASE_URI = "mysql://root:@localhost/boost"
